@@ -11,7 +11,6 @@
 # under the License.
 
 import uuid
-import warnings
 
 from keystoneclient import auth
 from keystoneclient import fixture
@@ -30,11 +29,6 @@ class BaseUserPluginTests(object):
                              auth_plugin,
                              group='keystone_authtoken',
                              **kwargs):
-        # NOTE(gyee): For this test suite and for the stable liberty branch
-        # only, we will ignore deprecated calls that keystonemiddleware makes.
-        warnings.filterwarnings('ignore', category=DeprecationWarning,
-                                module='^keystonemiddleware\\.')
-
         opts = auth.get_plugin_class(auth_plugin).get_options()
         self.cfg.register_opts(opts, group=group)
 
@@ -66,7 +60,6 @@ class BaseUserPluginTests(object):
         m = self.create_simple_middleware()
 
         resp = self.call(m, headers=headers)
-        self.assertEqual(200, resp.status_int)
         return resp.request.environ['keystone.token_auth']
 
     def test_user_information(self):
